@@ -224,6 +224,8 @@ class RunsHandler(BaseHandler):
             # self._accessKey = data.get("accessKey", "")
             serverURL = data.get("serverURL", "")
             accessKey = data.get("accessKey", "")
+            project = data.get("project", "")
+            sub_project = data.get("subproject", "")
 
             # if not self._serverURL or not self._accessKey or self._serverURL == "" or self._accessKey == "":
             #     self.error_response(404, "ServerError",
@@ -236,7 +238,7 @@ class RunsHandler(BaseHandler):
 
             runs = []
             dataplate = DataPlate(access_key=accessKey, dataplate_uri=serverURL)
-            generator = dataplate.list_runs_notebook(n=20)
+            generator = dataplate.list_runs_notebook(n=20,project=project,sub_project=sub_project)
             for run in json.loads(generator.reset_index().to_json(orient='records')):
                 # self.log.debug(f'Described run job: {run["name"]}')
                 await asyncio.sleep(0)
@@ -735,6 +737,88 @@ class SubProjectsHandler(BaseHandler):
             self.error_response(500, "ServerError", str(se))
 
 
+class ScanHandler(BaseHandler):
+
+    @tornado.web.authenticated
+    def post(self, notebook_name):
+        try:
+            data = json.loads(self.request.body.decode("utf-8"))
+            if data is None:
+                return
+            # self.log.debug(f'invoke now data: {notebook_name}')
+            # self.log.debug(f'invoke now data: {data}')
+
+            serverURL = data.get("serverURL", "")
+            accessKey = data.get("accessKey", "")
+
+            if not serverURL or not accessKey or serverURL == "" or accessKey == "":
+                self.error_response(404, "ServerError",
+                                    "DataPlate Configuration is invalid, please set your Server URL and Access Key")
+                return
+
+            kwargs = dict(
+                notebook_file_path=data["notebook_file_path"]
+            )
+
+            dataplate = DataPlate(access_key=accessKey, dataplate_uri=serverURL)
+            df_compromise = dataplate.scan_notebook(**kwargs)
+            # self.log.debug(f'df_compromise: {df_compromise}')
+            if notebook_name and str(notebook_name).endswith('.ipynb'):
+                notebook_name = notebook_name[:-6]
+            report_file_name = 'security_report_' + notebook_name + '_' + datetime.datetime.strftime(datetime.datetime.now(),'%Y-%m-%d-%X') + '.html'
+            # self.log.debug(f'report_file_name: {report_file_name}')
+            df_compromise.to_html(report_file_name)
+            # with open(localReportHtmlFileName, 'r') as file:
+            #     filedata = file.read()
+            self.json_response({"report_name": report_file_name})
+        except botocore.exceptions.ClientError as e:
+            self.client_error_response(e)
+        except botocore.exceptions.BotoCoreError as e:
+            self.botocore_error_response(e)
+        except Exception as ex:
+            self.error_response(500, "ServerError", str(ex))
+        except SystemExit as se:
+            self.error_response(500, "ServerError", str(se))
+
+
+class ReportStatisticsHandler(BaseHandler):
+
+    @tornado.web.authenticated
+    def post(self):
+        try:
+            data = json.loads(self.request.body.decode("utf-8"))
+            if data is None:
+                return
+            # self.log.debug(f'invoke now data: {notebook_name}')
+            # self.log.debug(f'invoke now data: {data}')
+
+            serverURL = data.get("serverURL", "")
+            accessKey = data.get("accessKey", "")
+            notebook_name = data.get("notebook_name", "")
+
+            if not serverURL or not accessKey or serverURL == "" or accessKey == "":
+                self.error_response(404, "ServerError",
+                                    "DataPlate Configuration is invalid, please set your Server URL and Access Key")
+                return
+
+            kwargs = dict(
+                notebook_name=notebook_name,
+                embed_report=False
+            )
+
+            dataplate = DataPlate(access_key=accessKey, dataplate_uri=serverURL)
+            report_file_name = dataplate.report_statistic(**kwargs)
+
+            self.json_response({"report_name": report_file_name})
+        except botocore.exceptions.ClientError as e:
+            self.client_error_response(e)
+        except botocore.exceptions.BotoCoreError as e:
+            self.botocore_error_response(e)
+        except Exception as ex:
+            self.error_response(500, "ServerError", str(ex))
+        except SystemExit as se:
+            self.error_response(500, "ServerError", str(se))
+
 
 class RouteHandler(APIHandler):
     # The following decorator should be present on all verb methods (head, get, post,
@@ -762,9 +846,12 @@ def setup_handlers(web_app):
     datasets_pattern = url_path_join(base_url, prefix, "datasets")
     projects_pattern = url_path_join(base_url, prefix, "projects")
     subprojects_pattern = url_path_join(base_url, prefix, "subprojects/(.+)")
+    scan_pattern = url_path_join(base_url, prefix, "scan/(.+)")
+    reportstatistics_pattern = url_path_join(base_url, prefix,"reportstatistics")
     handlers = [(route_pattern, RouteHandler), (schedule_pattern, RulesHandler),(schedule_details_pattern,RuleHandler),
                 (run_details_pattern,RunHandler),(runs_pattern,RunsHandler),(output_pattern,OutputHandler),(invoke_pattern,InvokeHandler),
-                (datasets_pattern,DatasetsHandler),(projects_pattern,ProjectsHandler),(subprojects_pattern,SubProjectsHandler)]
+                (datasets_pattern,DatasetsHandler),(projects_pattern,ProjectsHandler),(subprojects_pattern,SubProjectsHandler),(scan_pattern,ScanHandler),
+                (reportstatistics_pattern,ReportStatisticsHandler)]
 
     # prefix = "/dataplate-lab/"
     # handlers = [
