@@ -30,8 +30,12 @@ import {
   CreateRuleRequest,
   CreateRuleResponse,
   ErrorResponse,
+  ScanRequest,
+  ScanResponse,
+  StatisticsReportRequest,
+  StatisticsReportResponse,
 } from '../server';
-import { InputColumn, LabeledTextInput, LabeledPasswordInput, LabeledNumberInput } from './InputColumn';
+import { InputColumn, LabeledTextInput, LabeledPasswordInput, LabeledNumberInput, LabeledTextInputMaxWidth } from './InputColumn';
 import { ParameterEditor, ParameterKV } from './ParameterEditor';
 import { Alert, AlertProps } from './Alert';
 
@@ -74,6 +78,8 @@ interface PersistentState {
   securityGroups: string;
   subnets: string;
   maxMinutes: string;
+  project: string;
+  subproject: string;
 }
 interface ISchedulePanelState extends PersistentState {
   notebook: string;
@@ -118,6 +124,8 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
       securityGroups: '',
       subnets: '',
       maxMinutes: '120',
+      project: null,
+      subproject: null,
     };
 
     this.loadState();
@@ -157,6 +165,7 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
       <div>
         {this.renderConfigParams()}
         {this.renderViewButtons()}
+        {this.renderRunsFilterParams()}
         {this.renderCurrentNotebook()}
       </div>
     );
@@ -235,15 +244,47 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
               label="DataPlate Server URL:"
               value={this.state.serverURL}
               title="DataPlate Server URL to communicate with"
+              placeholder=""
               onChange={this.onServerUrlChange}
             />
             <LabeledPasswordInput
               label="DataPlate Access Key:"
               value={this.state.accessKey}
               title="DataPlate Access Key to use for specific user"
+              placeholder=""
               onChange={this.onAccessKeyChange}
             />
           </InputColumn>
+          <a href="https://api.dataplate.io/reference/api-reference" style={{'color': 'blue'}} target="_blank" rel="noreferrer">
+            <i className="fa fa-info-circle blueiconcolor"> <u>Dataplate API</u></i>
+          </a>
+        </div>
+      </div>
+    );
+  }
+
+
+  private renderRunsFilterParams() {
+    return (
+        <div className={runSidebarSectionClass}>
+        <header>Filter runs by project/sub-project</header>
+        <div>
+          <InputColumn>
+            <LabeledTextInputMaxWidth
+              label=""
+              value={this.state.project}
+              title="Filter notebook runs by project"
+              placeholder="Filter by project name"
+              onChange={this.onProjectChange}
+            />
+            <LabeledTextInputMaxWidth
+              label=""
+              value={this.state.subproject}
+              title="Filter notebook runs by sub-project"
+              placeholder="Filter by sub-project name"
+              onChange={this.onSubProjectChange}
+            />
+          </InputColumn>
         </div>
       </div>
     );
@@ -266,6 +307,7 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
     );
   }
 
+
   private renderRunParameters() {
     return (
       <div className={runSidebarSectionClass}>
@@ -280,36 +322,42 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
             label="Image:"
             value={this.state.image}
             title="ECR image to use"
+            placeholder=""
             onChange={this.onImageChange}
           />
           <LabeledTextInput
             label="Role:"
             value={this.state.role}
             title="IAM role to use"
+            placeholder=""
             onChange={this.onRoleChange}
           />
           <LabeledTextInput
             label="Instance:"
             value={this.state.instanceType}
             title="Instance type to run on"
+            placeholder=""
             onChange={this.onInstanceTypeChange}
           />
           <LabeledTextInput
             label="Security Group IDs:"
             value={this.state.securityGroups}
             title="Security groups separated by comma"
+            placeholder=""
             onChange={this.onSecurityGroupsChange}
           />
           <LabeledTextInput
             label="Subnets:"
             value={this.state.subnets}
             title="Subnets separated by comma"
+            placeholder=""
             onChange={this.onSubnetsChange}
           />
           <LabeledNumberInput
             label="Max run minutes:"
             value={this.state.maxMinutes}
             title="Maximum minutes to run the job"
+            placeholder=""
             onChange={this.onMaxMinutesChange}
           />
         </InputColumn>
@@ -326,18 +374,21 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
             label="Rule Name:"
             value={this.state.ruleName}
             title="A name for this schedule"
+            placeholder=""
             onChange={this.onRuleNameChange}
           />
           <LabeledTextInput
             label="Schedule:"
             value={this.state.schedule}
             title="Schedule for the notebook run"
+            placeholder=""
             onChange={this.onScheduleChange}
           />
           <LabeledTextInput
             label="Event Pattern:"
             value={this.state.eventPattern}
             title="Events to trigger the notebook run"
+            placeholder=""
             onChange={this.onEventPatternChange}
           />
         </InputColumn>
@@ -364,13 +415,20 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
               value="Create Schedule"
               onClick={this.onScheduleClick}
             />
-            {/*<input*/}
-            {/*  className={sidebarButtonClass}*/}
-            {/*  type="button"*/}
-            {/*  title="Scan the notebook"*/}
-            {/*  value="Scan Now"*/}
-            {/*  onClick={this.onScheduleClick}*/}
-            {/*/>*/}
+            <input
+              className={sidebarButtonClass}
+              type="button"
+              title="Statistics Report for the notebook saved statistics"
+              value="Statistics Report"
+              onClick={this.onStatisticsReportClick}
+            />
+            <input
+              className={sidebarButtonClass}
+              type="button"
+              title="Scan the notebook"
+              value="Security Scan"
+              onClick={this.onScanClick}
+            />
           </div>
         </div>
       </div>
@@ -435,8 +493,17 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
     this.setState({ eventPattern: event.target.value }, () => this.saveState());
   };
 
+  private onProjectChange = (event: React.ChangeEvent<HTMLInputElement>): void => {
+    this.setState({ project: event.target.value }, () => this.saveState());
+  };
+
+  private onSubProjectChange = (event: React.ChangeEvent<HTMLInputElement>): void => {
+    this.setState({ subproject: event.target.value }, () => this.saveState());
+  };
+
   private onRunListClick = async (): Promise<void> => {
     this.props.runsModel.setDataplateServerKey(this.state.serverURL,this.state.accessKey)
+    this.props.runsModel.setProject(this.state.project,this.state.subproject)
     this.app.commands.execute('dataplate-lab:open_list_runs');
   };
 
@@ -664,6 +731,149 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
     return data.rule_name;
   }
 
+  ////////////////////////
+  /* START SECURITY SCAN*/
+  ////////////////////////
+
+  private onScanClick = async (): Promise<void> => {
+    console.log('Scan Notebook!!!');
+    this.clearAlerts();
+    try {
+      this.addAlert({
+        type: 'notice',
+        message: `Scanning Notebook "${this.state.notebook}"`,
+      });
+
+      const request: ScanRequest = {
+        notebook_file_path: this.currentNotebookPanel.context.contentsModel.path,
+        serverURL: this.state.serverURL,
+        accessKey: this.state.accessKey,
+      };
+
+      const report_name = await this.scanNotebook(this.state.notebook, request);
+      this.addAlert({ message: `Scan finished successfully for notebook ${this.state.notebook}, open report file ${report_name} from your root folder`});
+      console.log(`Scan finished successfully for notebook ${this.state.notebook}, open report file ${report_name}`);
+    } catch (e) {
+      this.addAlert({
+        type: 'error',
+        message: `Error scan notebook "${this.state.notebook}": ${e.message}`,
+      });
+    }
+  };
+
+  // Return an array of reasons that we can't scan a notebook.
+  private scanReady(): string[] {
+    const result: string[] = [];
+    if (!this.state.notebook) {
+      result.push('missing notebook name - did you save your notebook ?');
+    }
+    if (!this.currentNotebookPanel.context.contentsModel.path.endsWith('.ipynb')) {
+      result.push('Youe `CURRENT NOTEBOOK` must be a proper notebook file with extension .ipynb');
+    }
+    return result;
+  }
+
+  private async scanNotebook(notebookName: string, request: ScanRequest): Promise<string> {
+    const errors = this.scanReady();
+    if (errors.length > 0) {
+      throw new Error(errors.join(', '));
+    }
+    const settings = ServerConnection.makeSettings();
+
+    const response = await ServerConnection.makeRequest(
+      URLExt.join(settings.baseUrl, 'dataplate-lab', 'scan', notebookName),
+      { method: 'POST', body: JSON.stringify(request) },
+      settings,
+    );
+
+    if (!response.ok) {
+      const error = (await response.json()) as ErrorResponse;
+      let errorMessage: string;
+      if (error.error) {
+        errorMessage = error.error.message;
+      } else {
+        errorMessage = JSON.stringify(error);
+      }
+      throw Error(errorMessage);
+    }
+
+    const data = (await response.json()) as ScanResponse;
+    return data.report_name;
+  }
+
+  ///* END SECURITY SCAN *///
+
+
+  ////////////////////////////
+  /* START Statistics Report*/
+
+  private onStatisticsReportClick = async (): Promise<void> => {
+    console.log('Statistics Report for Notebook!!!');
+    this.clearAlerts();
+    try {
+      this.addAlert({
+        type: 'notice',
+        message: `Generating statistics report (5 last runs) for Notebook "${this.state.notebook}"`,
+      });
+
+      const request: StatisticsReportRequest = {
+        notebook_name: this.state.notebook,
+        serverURL: this.state.serverURL,
+        accessKey: this.state.accessKey,
+      };
+
+      const report_name = await this.statisticsReportNotebook(request);
+      this.addAlert({ message: `Statistics report finished successfully for notebook ${this.state.notebook}, open report file ${report_name} from your root folder`});
+      console.log(`Statistics report finished successfully for notebook ${this.state.notebook}, open report file ${report_name}`);
+    } catch (e) {
+      this.addAlert({
+        type: 'error',
+        message: `Error generating statistics report for notebook "${this.state.notebook}": ${e.message}`,
+      });
+    }
+  };
+
+  // Return an array of reasons that we can't scan a notebook.
+  private statisticsReportReady(): string[] {
+    const result: string[] = [];
+    if (!this.state.notebook) {
+      result.push('missing notebook name - did you save your notebook ?');
+    }
+    return result;
+  }
+
+  private async statisticsReportNotebook(request: StatisticsReportRequest): Promise<string> {
+    const errors = this.statisticsReportReady();
+    if (errors.length > 0) {
+      throw new Error(errors.join(', '));
+    }
+    const settings = ServerConnection.makeSettings();
+
+    const response = await ServerConnection.makeRequest(
+      URLExt.join(settings.baseUrl, 'dataplate-lab', 'reportstatistics'),
+      { method: 'POST', body: JSON.stringify(request) },
+      settings,
+    );
+
+    if (!response.ok) {
+      const error = (await response.json()) as ErrorResponse;
+      let errorMessage: string;
+      if (error.error) {
+        errorMessage = error.error.message;
+      } else {
+        errorMessage = JSON.stringify(error);
+      }
+      throw Error(errorMessage);
+    }
+
+    const data = (await response.json()) as StatisticsReportResponse;
+    return data.report_name;
+  }
+
+
+  /* END Statistics Report*/
+  //////////////////////////
+
   private alertKey = 0;
   private addAlert(alert: AlertProps) {
     const key = this.alertKey++;
@@ -689,6 +899,8 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
       securityGroups: this.state.securityGroups,
       subnets: this.state.subnets,
       maxMinutes: this.state.maxMinutes,
+      project: this.state.project,
+      subproject: this.state.subproject,
     };
 
     this.props.stateDB.save(KEY, state);
@@ -710,6 +922,8 @@ export class SchedulePanel extends React.Component<ISchedulePanelProps, ISchedul
           securityGroups: state['securityGroups'] as string,
           subnets: state['subnets'] as string,
           maxMinutes: state['maxMinutes'] as string,
+          project: state['project'] as string,
+          subproject: state['subproject'] as string,
         });
       }
     });
